import React, { useEffect, useState } from 'react';
import { NavigationContainer } from '@react-navigation/native';
import { createNativeStackNavigator } from '@react-navigation/native-stack';
import * as Linking from 'expo-linking';
import PlayerScreen from './src/screens/PlayerScreen';
import HomeScreen from './src/screens/HomeScreen';
import { StatusBar } from 'expo-status-bar';

// AdMob Configuration
// Application ID: ca-app-pub-3808259283882168~6546457972
// In a real implementation with the AdMob SDK, we would configure it here

// Define the type for our navigation parameters
export type RootStackParamList = {
  Home: undefined;
  Player: { 
    videoUrl: string; 
    title?: string; 
    thumbnail?: string;
    contentType?: 'movie' | 'series' | 'channel' | 'match';
  };
};

const Stack = createNativeStackNavigator<RootStackParamList>();

const prefix = Linking.createURL('/');

export default function App() {
  const [data, setData] = useState<any>(null);

  const linking = {
    prefixes: [prefix, 'saqrplayer://', 'https://saqrplayer.com'],
    config: {
      screens: {
        Home: 'home',
        Player: 'play',
      },
    },
    async getInitialURL() {
      // First, try to get the initial URL from Expo's Linking API
      const initialUrl = await Linking.getInitialURL();
      
      if (initialUrl) {
        return initialUrl;
      }
      
      return null;
    },
    subscribe(listener: (url: string) => void) {
      // Listen to incoming links from deep linking
      const subscription = Linking.addEventListener('url', ({ url }) => {
        listener(url);
      });

      return () => {
        subscription.remove();
      };
    },
  };

  return (
    <NavigationContainer linking={linking}>
      <StatusBar style="light" />
      <Stack.Navigator 
        initialRouteName="Home"
        screenOptions={{
          headerStyle: {
            backgroundColor: '#121212',
          },
          headerTintColor: '#E50914',
          headerTitleStyle: {
            fontWeight: 'bold',
          },
          animation: 'slide_from_right',
        }}
      >
        <Stack.Screen 
          name="Home" 
          component={HomeScreen} 
          options={{ title: 'Saqr Player' }} 
        />
        <Stack.Screen 
          name="Player" 
          component={PlayerScreen}
          options={({ route }) => ({ 
            title: route.params?.title || 'Video Player',
            headerShown: false 
          })}  
        />
      </Stack.Navigator>
    </NavigationContainer>
  );
}